@@ -471,7 +471,7 @@ class Gravity:
         flow_df.apply(lambda flow_example: self._update_training_set(flow_example), axis=1)
 
         # Perform GLM fit
-        poisson_model = GLM(self.y, self.X, family=sm.genmod.families.family.Poisson(link=sm.genmod.families.links.log))
+        poisson_model = GLM(self.y, self.X, family=sm.genmod.families.family.Poisson(link=sm.genmod.families.links.log()))
         poisson_results = poisson_model.fit()
 
         # Set best fit parameters
